@@ -6,7 +6,28 @@ import time
 
 
 @retry(exceptions=Exception, tries=3, delay=2, backoff=2)
-def update_github(token, repo_name, filename):
+def download_github_file(token, repo_name, filename):
+    # 獲取當前工作目錄路徑
+    cwd = os.path.abspath(os.getcwd())
+
+    # 使用 token 連接 Github API
+    g = Github(token)
+    user = g.get_user()
+    repo = user.get_repo(repo_name)
+
+    # 獲取檔案內容
+    file_content = repo.get_contents(filename)
+    file_content_str = file_content.decoded_content.decode("utf-8")
+
+    # 寫入本地檔案
+    with open(os.path.join(cwd, filename), "w") as f:
+        f.write(file_content_str)
+
+    print(f"{filename} downloaded")
+
+
+@retry(exceptions=Exception, tries=3, delay=2, backoff=2)
+def update_github_file(token, repo_name, filename):
     # 獲取當前工作目錄路徑
     cwd = os.path.abspath(os.getcwd())
 
